@@ -119,6 +119,8 @@ private slots:
     //! Invoked when user invokes refresh
     void onRefreshAll ();
 
+    void onStatusTimerTick ();
+
 private:
     void initLogging ();
     void doLogin ();
@@ -159,6 +161,9 @@ private:
     //! Web View
     WebWidget      *pWebWidget;
 
+    //! Timer for status messages
+    QTimer          statusTimer;
+
 #ifdef Q_WS_MAEMO_5
     QMaemo5InformationBox   infoBox;
 #endif
